#
# spec file for package python-pydata-sphinx-theme
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define skip_python36 1
%{?sle15_python_module_pythons}
Name:           python-pydata-sphinx-theme
Version:        0.15.4
Release:        2.0.2.1.sr20241103
Summary:        Bootstrap-based Sphinx theme from the PyData community
License:        BSD-3-Clause
URL:            https://github.com/pydata/pydata-sphinx-theme
Source:         pydata-sphinx-theme-%{version}.tar.gz
# Source: https://files.pythonhosted.org/packages/source/p/pydata-sphinx-theme/pydata_sphinx_theme-%%{version}.tar.gz
# Source1 and Source2 created with ./prepare_vendor.sh
Source1:        python-pydata-sphinx-theme-%{version}-vendor.tar.xz
Source2:        python-pydata-sphinx-theme-%{version}-vendor-licenses.txt
Source99:       prepare_vendor.sh
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module sphinx-theme-builder}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Babel
Requires:       python-Sphinx
Requires:       python-accessible-pygments
Requires:       python-beautifulsoup4
Requires:       python-docutils
Requires:       python-packaging
Requires:       python-pygments
Requires:       python-sphinx-theme-builder
Requires:       python-typing_extensions
Suggests:       python-beautifulsoup4
Suggests:       python-codecov
Suggests:       python-docutils
Suggests:       python-jupyter_sphinx
Suggests:       python-numpy
Suggests:       python-numpydoc
Suggests:       python-pandas
Suggests:       python-plotly
Suggests:       python-recommonmark
Suggests:       python-Sphinx
Suggests:       python-xarray
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module pygments}
BuildRequires:  %{python_module Babel}
BuildRequires:  %{python_module Sphinx}
BuildRequires:  %{python_module accessible-pygments}
BuildRequires:  %{python_module beautifulsoup4}
BuildRequires:  %{python_module docutils}
BuildRequires:  %{python_module packaging}
BuildRequires:  %{python_module pytest-regressions}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module typing_extensions}
BuildRequires:  nodejs-default
BuildRequires:  nodejs-devel
BuildRequires:  nodejs-packaging
BuildRequires:  yarn

# /SECTION
%python_subpackages

%description
Bootstrap-based Sphinx theme from the PyData community

%prep
%autosetup -p1 -n pydata-sphinx-theme-%{version} -a1
sed -i 's,^\(node-version = \)".*",\1"%{nodejs_version}",' pyproject.toml

# Create a node header tarball so we don't try to download it
mkdir -p node-v%{nodejs_version}/include
cp -a %{_includedir}/node* node-v%{nodejs_version}/include/node
tar czf node-v%{nodejs_version}-headers.tar.gz node-v%{nodejs_version}
echo "tarball=\"$PWD/node-v%{nodejs_version}-headers.tar.gz\"" > .npmrc

%build
export STB_USE_SYSTEM_NODE=1
export PUPPETEER_SKIP_CHROMIUM_DOWNLOAD=1
export YARN_CACHE_FOLDER="$PWD/.package-cache"
export NODE_OPTIONS=--openssl-legacy-provider
yarn install --offline

# nodeenv generated with python3, no need to generate a different
# nodeenv for each flavor
python%python_bin_suffix -m nodeenv --node=system --prebuilt --clean-src $PWD/.nodeenv
%pyproject_wheel

%install
%pyproject_install
%python_expand rm -rf %{buildroot}%{$python_sitelib}/pydata_sphinx_theme/theme/pydata_sphinx_theme/static/.gitignore
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# No python-playwrite optional dependency gh#pydata/pydata-sphinx-theme#1541
donttest="test_pygments_fallbacks"
%pytest -k "not $donttest"

%files %{python_files}
%doc README.md
%license LICENSE
%{python_sitelib}/pydata_sphinx_theme*

%changelog
* Wed Sep 25 2024 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
- Fix build error under Leap.
* Mon Sep  2 2024 mcepl@cepl.eu
- Regenerate vendored js libraries (bsc#1229866).
- Update to version 0.15.4:
  * bump: 0.15.4rc0 → 0.15.4
  * ENH - Update copyright.html to not include the html tags. (#1874)
  * Fix url shortening for gitlab, and more test for github (#1888)
  * MAINT: Bump treosh/lighthouse-ci-action from 11 to 12 (#1899)
  * docs: update note formatting (#1893)
  * docs: update badge link (#1892)
  * Instruction to install alpha, beta, rc and nightly (#1891)
  * bump: 0.15.3 → 0.15.4rc0
  * MAINT: simpleify _generate_header_nav_before_dropdown (#1883)
  * A11Y - Add visual indicator for tabs hover (#1884)
  * Fix hit area icon links buttons (#1866)
  * Build(deps-dev): Bump braces from 3.0.2 to 3.0.3 and fill-range 7.0.1 to 7.1.1 (#1881)
  * bump sphinxcontrib-youtube (#1877)
  * fix config var names in docs (#1878)
  * BUG - Ensure coverage comment is triggered (#1879)
  * guard a couple (possibly null) querySelector results (#1860)
  * Updates for italian translation (#1862)
  * Do not apply table colors to all tables, only css=.table (#1864)
  * MAINT: Upload nightly wheels and run packaging on PRs and pushes (#1867)
  * Use navbar-nav class on text links only (#1846)
  * Updates for file src/pydata_sphinx_theme/locale/en/LC_MESSAGES/sphinx.po in ca (#1858)
  * MAINT: Reenable parallel write safety (#1859)
  * Expose logo_link in theme.conf (#1850)
  * DOCS: Add navbar_persistent to overview layout (#1849)
  * CI - Remove lint from CI (#1856)
  * [pre-commit.ci] pre-commit autoupdate hooks (#1848)
  * Updates for file src/pydata_sphinx_theme/locale/en/LC_MESSAGES/sphinx.po in es (#1845)
  * Add documentation for the back_to_top_button config option (#1843)
  * Inheritance Diagram Dark Mode Support (#1834)
  * bump version to dev
  * release 0.15.3
  * Update luminance coefficient (#1837)
  * Add stylelint fixes to .git-blame-ignore-revs file (#1836)
  * [pre-commit.ci] Automatic linting and formatting fixes
  * delete unused -var
  * Manual fixes for stylelint
  * Manual adjustments to autofixes
  * Autofix (stylelint)
  * Add stylelint hook and config
  * Correctly specify the source path to a logo to copy_asset_file (#1746)
  * Various table fixes (#1833)
  * Set banner height to auto after animation (#1830)
  * DEV -  Update workflows (#1831)
  * Fix keyboard access for scrollable regions created by notebook outputs (#1787)
  * Move CSS block out of SCSS vars file (#1832)
  * DEV - Refactor CI and environment setup (#1759)
  * Track if users has dismissed a version warning banner for a given version. (#1763)
  * Add CSS to allow scrolling of ipywidget (#1760)
  * Animate remotely loaded banners together (#1808)
  * Add a pre-commit hook that remove PO files metadata. (#1813)
  * Wrap tables in scrollable div (#1827)
  * Refactor navbar generating function (#1780)
  * fix: deprecate pygments related variable to correct typos (#1614)
  * Add GitHub action timeout (#1826)
  * Raise exception for response codes outside range 200-299 (#1755)
  * Updates for file src/pydata_sphinx_theme/locale/en/LC_MESSAGES/sphinx.po in fr (#1801)
  * fix version-switcher with dirhtml builder (#1795)
  * Remove backwards-compatible text-decoration-skip rule (#1820)
  * Remove hack to fix bug with up/down keys and "More" links in sidebar (#1819)
  * Revert "fix perms in publish workflow" (#1815)
  * fix perms in publish workflow (#1814)
  * bump: 0.15.3rc2 → 0.15.3
  * center figure and captions inside figwith, while the whole figure is left/right (#1750)
  * Exclude copy button from notebook cell numbers (#1811)
  * MAINT - Add env variable to control test-them build location. (#1800)
  * a11y - Implement @smeragoel's table designs (#1757)
  * MAINT - Purge codecov (#1809)
  * Provide copy button container sufficient min height (#1810)
  * DEV - Update pygments tests (#1807)
  * Do not generate dropdown in sidebar. (#1771)
  * MAINT: various fixes to print CSS. (#1770)
  * Allow paragraph elements to inherit color (#1762)
  * Try to implement coverage action instead of using codecov. (#1756)
  * Update release action (#1803)
  * Remove :hover pseudo-class from link-style-hover mixin (#1792)
  * Make announcement banner into a landmark (aside/complementary) (#1793)
  * [pre-commit.ci] pre-commit autoupdate hooks (#1806)
  * bump: 0.15.3rc0 -> 0.15.3rc1 (#1802)
  * bump: 0.15.2 → 0.15.3
  * Fix blockquote color contrasts (#1786)
  * Fix GUI label contrast (#1790)
  * Wait for CSS transitions before running Axe scan (#1785)
  * MAINT: Fix some types (#1779)
  * Only make scrollable code blocks into tab stops (#1777)
  * Fix selector for table-layout rule (#1761)
  * Fix alignment of sidebar TOC entries (#1775)
  * Fix focus ring glitch on API autosummary "[source]" link (#1778)
  * Install sphinx test dependencies in all CI testing jobs (#1772)
  * FEAT - Restyle interactive elements to be more accessible (#1564)
  * tiny CSS change (#1769)
  * fix: use the latest minor version of fontawesome 6 (#1768)
  * optimize figure bottom margin (#1749)
  * CI - Swap to trusted publisher for releases (#1758)
  * Ensure code blocks (<pre>) are keyboard focusable (#1636)
  * Build(deps): Bump pre-commit/action from 3.0.0 to 3.0.1 (#1715)
  * Fix missing sphinx testing dependencies (#1751)
  * DEV - Enable pre-commit ci  (#1752)
  * docs: add the link to the transifex project (#1707)
  * BUG - Fix violation of Axe rule link-name (#1633)
  * make codecov work better (#1741)
  * space icon-links evenly across (#1726)
  * fix URLs for dirhtml builds (#1699)
  * try to fix codecov (#1717)
  * FIX secondary sidebar persists even if it is empty (#1688)
  * Do not show announcement banner if announcement contents are empty (#1703)
  * Fix and change a11y tests (#1687)
  * BUG - Ensure lists markers colours are visible (#1711)
  * chore(i18n): create cs translation (#1716)
  * chore(i18n): update ca translation (#1713)
  * Updates for file src/pydata_sphinx_theme/locale/en/LC_MESSAGES/sphinx.po in es (#1712)
  * remove deprecated configs and associated code/tests (#1698)
  * Build(deps): Bump treosh/lighthouse-ci-action from 10 to 11 (#1705)
  * Build(deps): Bump codecov/codecov-action from 3 to 4 (#1706)
  * docs: typo in a link in the release instructions (#1704)
  * ENH animation for the top banner (#1693)
  * ENH make search result heading a bit away from the search input box (#1690)
  * handle null result from queryselector (#1683)
  * Don't try to populate version switcher w/ relative path on local static site (#1660)
  * Apply default_mode to the html data-theme attribute (#1663)
  * Restore search snippet highlights in search results page (#1678)
  * only do security updates for NPM (#1674)
  * update dependabot labels (#1668)
  * Build(deps): Bump actions/cache from 3 to 4 (#1667)
  * FIX make search button closer to other icons in topbar (#1659)
  * unpin sphinx in CI (#1665)
  * FIX make theme switcher have consistent widths (#1651)
  * bump version to dev
  * bump: 0.15.1 -> 0.15.2
  * in CIs, pin sphinx dev temporarily
  * remove toggle button for secondary sidebar if empty (#1637)
  * fix: allow user to control the back-to-top button presence (#1616)
  * Allow only theme_footer_center to be set (#1653)
  * More speedups to section TOC rendering (#1642)
  * Make search event listener only trigger with “K”/“k” (#1646)
  * fix: move the release instructions to the repository (#1621)
  * Add Brightway to Featured Example Gallery Grid (#1580)
  * Make bootstrap globally available (#1639)
  * DOC: Add missing "footer_center" in layout overview diagram (#1640)
  * maybe fix missing sidebar? (#1632)
  * Fix sticky header (#1630)
  * fix: align the search button with other icons (#1620)
  * back to dev
  * bump: 0.15.0 → 0.15.1
  * fix: log information when warnings are disabled (#1617)
  * fix: align all breadcrumb elements (#1619)
  * fix: remove Site navigation header (#1615)
  * fix: drop the dev test (#1623)
  * bump: 0.14.4 → 0.15.0
  * Updates for file src/pydata_sphinx_theme/locale/en/LC_MESSAGES/sphinx.po in fr (#1618)
  * bump: 0.14.4 → 0.15.0rc0
  * Fix "More" links in mobile sidebar (#1604)
  * Fix: more efficient determination of when to hide primary sidebar (#1609)
  * Bump minimum Python from 3.8 to 3.9; add 3.12 to CIs (#1610)
  * Update translation files (#1606)
  * Feature: Add support for per-page secondary sidebar content (#1572)
  * Fix landmark-unique error due to in-page TOC (#1607)
  * Update fontawesome from 6.1.2 to 6.5.1 (#1600)
  * Build(deps): Bump actions/upload-artifact from 3 to 4 (#1598)
  * FIX: avoid implicit string comparison in Sphinx 7.26 (#1592)
  * Use pytest-regressions to mark expected a11y test failures (#1501)
  * Build(deps): Bump actions/setup-python from 4 to 5 (#1590)
  * Fix landmarks (#1454)
  * Flip chevrons when subtree is expanded (#1584)
  * fix: install pandoc in the a11y tests (#1576)
  * back to dev
  * bump: 0.14.3 → 0.14.4
  * Fix control + k keyboard shortcut (#1571)
  * fix: increase margins of autosummary tables (#1560)
  * Obviate background-from-color-variable (#1558)
  * docs: add data-content (#1559)
  * fix: primer link in docs (#1556)
  * docs: add the list of component using a directive (#1476)
  * chore: back to dev
  * bump: 0.14.2 → 0.14.3
  * Silence warnings (#1542)
  * fix: add color-theme option to html tag (#1536)
  * fix: make table background transparent (#1546)
  * docs: add instructions for custom SVG icons (#1490)
  * kill the docs-live infinite loop (yet again) (#1540)
  * back to dev
  * bump: 0.14.1 → 0.14.2
  * test: add a codecov token to the coverage pipeline (#1519)
  * build: update package-lock.json (#1534)
  * docs: add the full option reference in the docs (#1485)
  * use event.key for search shortcut (#1525)
  * refactor: remove extention on component set-up (#1529)
  * ignore transient errors in windows build CI (#1520)
  * Updates for file src/pydata_sphinx_theme/locale/en/LC_MESSAGES/sphinx.po in ru [Manual Sync] (#1527)
  * docs: add DecentralChain (#1528)
  * Fix font color in search input box (#1524)
  * chore: build the devcontainer automatically in codespace (#1483)
  * Fix duplicate HTML IDs (#1425)
  * Fix: (webpack.config.js) css-loader API change (#1508)
  * deps: drop support for Sphinx 5 (#1516)
  * fix: use 12rambau fork until it's merged with nikeee repo (#1517)
  * BUG - Clear alt_text in conf.py (#1471)
  * refactor: use nbsphinx as the default execution lib (#1482)
  * fix: convert "stable" to actual version number (#1512)
  * navigation_with_keys = False (#1503)
  * docs: link back to GitHub from PyPI metadata (#1504)
  * Update pst docs buttons (#1502)
  * Revert "Build(deps): Bump postcss and css-loader" (#1509)
  * Build(deps): Bump postcss and css-loader (#1494)
  * chore(i18n) catalan (#1488)
  * Change default logo alt text (#1472)
  * Add idtracker.ai to gallery.yaml (#1290)
  * bump: back to dev
  * bump: 0.14.0 → 0.14.1
  * docs: update dead link (#1466)
  * fix: truncate title in breadcrumbs (#1460)
  * temporarily pin sphinxcontrib-youtube (#1464)
  * fix: use project version (not theme version) in banner (#1446)
  * show ⌘ on Mac in both search button and search input field (#1449)
  * fix: set the same background for dark/light (#1443)
  * fix: change the z-index of the dropdown (#1442)
  * back to dev
* Tue Sep 19 2023 mmachova@suse.com
- Update to version 0.14.0:
  * bump: version 0.13.3 → 0.14.0  (#1440)
  * fix: rollback ref and Id changes (#1438)
  * Add dropdown_text argument to generate_header_nav_html (#1423)
  * Build(deps): Bump actions/checkout from 3 to 4 (#1433)
  * Add the ability to add a center section to the footer (#1432)
  * style(i18n): French Typo fixed (#1430)
  * BUG - Remove redundant ARIA in breadcrumb navigation (#1426)
  * Do not animate the version admonitions colors. (#1424)
  * Fix More dropdown (html, aria, bootstrap classes) (#1414)
  * fix: don't display the warning bar if there is an issue (#1420)
  * fix: place the las_update value in the meta of each page (#1409)
  * MAINT - Increase axe-core accessibility testing coverage (#1408)
  * MAINT: Test old and new Sphinx versions (#1413)
  * MAINT - Add css class dropdown-item to version switcher (#1411)
  * Fix TocTree manipulation on Sphinx 7.2+ (#1406)
  * Only use ``sphinx.testing.path`` on Sphinx 7.1 and earlier (#1405)
  * Update gallery.yaml (#1120)
  * Update switcher styling (#1400)
  * Fix docstring typo (#1399)
  * Add cashocs to example gallery (#1127)
  * Add new Brightway Documentation Page to pydata-sphinx Example Gallery (#1232)
  * docs: change rational of the gallery grid (#1390)
  * Fix redirection for pages missing in other docs versions (#1395)
  * Fix version warning banner message (#1394)
  * update version JSON config guidance (#1393)
  * fix: prevent link to be followed before testing the header (#1361)
  * Version warningbar (#1354)
  * fix: link to Sphinx's theme templating page (#1388)
  * MAINT: deprecations (#1381)
  * MAINT: fixes to tabbed examples in docs (#1379)
  * MAINT: badge alt-text in README.md (#1380)
  * fix infinite loop again (#1364)
  * BUG: fix highlighting of current version in switcher menu (#1357)
  * fix: use consistent markup in examples (#1373)
  * docs: use an admonition instead of "!!" (#1374)
  * Fix some CSS header bugs on mobile (#1376)
  * MAINT: Miscellaneous improvements to this theme (#1377)
  * core: drop support python 3.7 (#1369)
  * feat: add a scroll to top btn (#1332)
  * ENH - Update links styling (#1353)
  * ENH: Add search button that looks like field (#1233)
  * fix theme elements page (#1356)
  * fix: make redirection work when page is not existing in previous version (#1350)
  * remove pandas API from the documentation (#1330)
  * ENH - Scalable colour system for theme (#1174)
  * fix: resolve path of switcher when using relative (#1344)
  * MAINT: fix local live doc build (#1349)
  * fix: create a dedicated area for the prev-next buttons (#1333)
  * fix: avoid infinite loop in docs-live (#1265)
  * fix: version switcher on sidebar (#1342)
  * docs: add osi badge
  * fix: set back align content for header navbar (#1331)
  * refactor: remove custom scrollbars (#1337)
  * Build(deps): Bump codecov/codecov-action from 3.1.3 to 3.1.4 (#1334)
  * first 'es' automatic translation (#1298)
  * first 'fr' automatic translation (#1299)
  * ENH: include jupyterlite in the supported extention (#1023)
  * refactor: remove unused method (#1329)
  * DOC: update sample CSS for setting custom content width (#1318)
  * Update link to FontAwesome free icon gallery in the user guide (#1326)
  * Style keyword arguments in API docs (#1323)
  * BUG - Fix a11y tests call  (#1320)
  * sphinx 6 compat (#1314)
  * add new pandas error to allow list (#1310)
  * Override generation of `id` & `href` attributes for API documentation (#1208)
  * Build(deps): Bump treosh/lighthouse-ci-action from 9 to 10 (#1303)
  * Build(deps): Bump codecov/codecov-action from 3.1.2 to 3.1.3 (#1302)
  * Fix mispalced label tag in icon links component (#1300)
  * Accessibility test Kitchen Sink with Playwright (#1260)
  * fix: typo in the key names
  * feat: add transifex parameters (#1297)
  * fix: stop using squared icon for github and twitter (#1250)
  * FIX: Fix search icons displayed outside with small base font size (#1278)
  * try to fix codecov (#1289)
  * Fix footer appearing on top for short pages (#1277)
  * DOC: Section on RTD version switcher (#1280)
  * fix: add footer_end to the documentation (#1285)
  * Fix alignment of breacrumbs (#1282)
  * FIX: Remove index.html from version switcher example. (#1279)
  * back to dev
  * RLS: v0.13.3
  * refactor: spring cleaning (#1271)
  * bump: back to dev
  * RLS: v0.13.2
  * fix wheel by bumping STB version (#1272)
  * don't warn on fallback if no highlight theme was requested (#1264)
  * Update node packages and remove unneeded ones (#1258)
  * refactor: move all configs to pyproject.toml (#1268)
  * Fix typos found by codespell (#1261)
  * Add article and content footer components (#1215)
  * fix: right align text in footer end (#1245)
  * Add static assets guide (#1227)
  * docs: ensure edit links point to main branch (#1246)
  * fix: hide captions associated with hidden images (#1247)
  * MAINT: use fontawesome css variables instead of font names (#1219)
  * Fix broken Sphinx link in footer (#1234)
  * Main to dev0
* Thu May 18 2023 Dirk Müller <dmueller@suse.com>
- switch to nodejs-default
* Thu Mar  9 2023 Daniel Garcia <daniel.garcia@suse.com>
- Vendor all required nodejs modules to be able to build without
  network with the new sphinx-theme-builder
- Update to version 0.13.1:
  * RLS: v0.13.1
  * fix: deprecate use of the favicon config parameter (#1225)
  * MNT: more flexible static (#1221)
  * Fix icon links requirement (#1231)
  * DOCS: Fix `<p>` in docs for realz (#1224)
  * docs: remove legacy footer customization (#1229)
  * DOCS: Remove <p> from announcement sample text (#1223)
  * bump: dev0
* Mon Mar  6 2023 Daniel Garcia <daniel.garcia@suse.com>
- Update to version 0.13.0:
  * RLS: v0.13.0
  * Make heading-style use the font-weight-heading value (#1213)
  * dev0
  * RLS: v0.13.0rc6
  * FIX: Get theme options in a more robust way (#1214)
  * Dev0
  * RLS: 0.13.0rc5
  * FIX: Remove icon links component when no icon links given (#1209)
  * feat: Add full i18n support (#1192)
  * Use CSS transform for skip link (#1206)
  * Properly set configuration with app.builder.theme_options (#1199)
  * Add conditional check for last-updated template (#1201)
  * copy_logo_images: do not render dynamic Sphinx template content (#1204)
  * Fix math scrollbars for realz (#1198)
  * FIX: Make wide equations scroll (#1196)
  * Dev0
  * RLS: v0.13.0rc4
  * Fix github gitlab brand (#1194)
  * Refactor contributing docs to be more modular (#1173)
  * DOCS: Add internationalization instructions (#1178)
  * FIX: Some style bugs (#1191)
  * dev0
  * RLS: v0.13.0rc3
  * Minor style improvements to ablog (#1185)
  * maint: remove sphinx-panels support; remove deprecated config shims (#1188)
  * Standardize template structure in more sections (#1184)
  * maint: update GitLab URL tests (#1186)
  * fix: correctly add DOM listeners (#1179)
  * Properly handle default_mode=auto when writing logos (#1183)
  * “Edit this page” → “Edit on GitHub/GitLab/Bitbucket” (#1177)
  * Fix article header CSS (#1171)
  * DOCS: admonition customization (#1155)
  * RLS: v0.13.0rc2 (#1170)
  * Fix header vertical spacing and jupyter-sphinx cells (#1164)
  * Degrade gracefully when JavaScript is disabled (#1146)
  * ENH: Add breadcrumbs to article header (#1142)
  * FIX: Narrow scope of style rule for GitHub & GitLab link shortening (#1167)
  * remove emoji from landing page (#1151)
  * MAINT: update pypi classifiers (#1153)
  * FIX: Javascript incorrect check for variable (#1166)
  * Add test for internationalization and translations (#1138)
  * STYLE: lint the documentation with Doc8 (#1150)
  * FIX: Flex behavior should shrink header items instead of brand (#1158)
  * Copyright semicolon (#1160)
  * DOC: Use only shield.io for badges in README (#1152)
  * Build(deps): Bump http-cache-semantics from 4.1.0 to 4.1.1 (#1154)
  * Bump to dev0
  * 0.13.0rc1
  * Standardize logo image behavior between Sphinx and this theme (#1132)
  * ABlog: Updates for new HTML structure (#1118)
  * MAINT: update prerelease workflow (#1140)
  * MAINT: Refactor workflows to reduce test dependencies (#1136)
  * MAINT: Improve font sizing (#1129)
  * fix: use correct path for documentation logo
  * fix: align sidebar sliding with the buttons (#1123)
  * ENH/MAINT: avoid overwriting the HtmlTranslator (#1105)
  * FIX: Use logo_url instead deprecated logo in theme (#1094) (#1097)
  * Fix extra whitespace in sidebars (#1115)
  * feat: support leaflet maps in the theme (#1112)
  * Build(deps): Bump json5 from 1.0.1 to 1.0.2 (#1111)
  * MAINT: sphinx 4.0 behaviours are no longer supported (#1107)
  * FIX: Blog tag cloud overflow (#1093)
  * FIX: Center search keyboard buttons (#1103)
  * Fixing header height (#1102)
  * drop prettify to avoid extra space in inline block (#1101)
  * style dataframe included in a widget (#1089)
  * add matplotlib to the list of warnings (#1091)
  * Add Matplotlib to gallery.yaml (#1090)
  * FIX: remove DS_Store file (#1084)
  * make accessible-pygments a full dependency (#1083)
  * FIX: Update precommit (#1080)
  * Build(deps): Bump decode-uri-component from 0.2.0 to 0.2.2 (#1077)
  * Improving ABlog style and configuration (#1075)
  * Check for /-/ in GitLab url (closes #1073) (#1074)
  * Reduce the left padding for ul and ol lists (#1069)
  * MAINT: Lint html (#1021)
  * MAINT: use the github repo of flake8 in pre-commit (#1070)
  * MAINT: Drop jQuery and use Bootstrap 5 (#1029)
  * ENH: Accessible code highlighting styles (#1064)
  * Build(deps): Bump loader-utils from 1.4.1 to 1.4.2 (#1066)
  * bump version
  * RLS: v0.12.0
  * FIX: remove double quotes in github actions (#1062)
  * RLS: v0.12.0rc1 (#1057)
  * FIX: display external links in toctree (#1055)
  * STYLE: style admonitions (#1043)
  * Build(deps): Bump loader-utils from 1.4.0 to 1.4.1 (#1053)
  * FIX: use warning instead of errors for version json tests (#993)
  * ENH: Add GitHub Projects support for github shorten links (#1051)
  * FIX: Navigation buttons accessibility fixes (#1050)
  * ENH: Refactor gitlab parsing in ShortenLinkTransform (#1039) (#1048)
  * Disable CloudFlare Rocket loader on dark mode script (#1045)
  * Prerelease CI: Update name, schedule and Python version (#1044)
  * Change pypa/gh-action-pypi-publish to use stable release branch (#1047)
  * Add Dependabot configuration for GitHub Actions updates (#1046)
  * FIX: style table generated by myst-NB (#1041)
  * MAINT: refactor webpack.config.js (#1035)
  * ENH: support seealso admonition (#1037)
  * DOCS: update documentation link (#1033)
  * DOCS: fix python block in keyboard-shortcuts.md (#1032)
  * MAINT: split bootstrap and theme styling (#994)
  * ENH: Add skip to main content button for a11y (#1019)
  * MAINT: use a function to test the warnings of the CI doc build (#1002)
  * FIX: avoid API double select (#1015)
  * FIX: table width of nbsphinx dataframes (#1018)
  * DOCS: demonstrate inline highlighting (#1025)
  * ENH: create a navbar_persistent section (#1022)
  * ENH: place the RDT flyout in the sidebar (#1005)
  * FIX: update switcher list (#1009)
  * FIX: link shortening for gitlab (#1012)
  * FIX: make the icons available to implicit component (#991)
  * FIX: set back the icon inside the search bar (#992)
  * ENH: add the theme version in the footer (#1000)
  * FIX: avoid conflict between black and flake8
  * FIX: improve numbering of the docs (#1004)
  * fix: remove deprecated config (#997)
  * Remove deprecated option for google analytics (#975)
  * Remove travis/doctr cruft (#995)
  * Rename and add deprecation warnings for section names (#988)
  * FIX: change dark highlight for a11y (#985)
  * FIX: improve display of Hide search button (#984)
  * FIX: improve display of "side" docstring title (#981)
  * FIX: respect the align and width parameter of table directives (#968)
  * FIX: display math characters in the header navbar (#971)
  * Bump version
  * RLS: v0.11.0
  * fix: remove primary sidebar if empty (#980)
  * Bump version
  * RLS: v0.11.0rc3
  * Support Sphinx 4.2+ (#978)
  * Bump version
  * RLS: v0.11.0rc2
  * Fix for publishing prereleases (#974)
  * RLS: v0.11.0rc1
  * Test on Python 3.11 (#972)
  * FIX: check the json switcher file (#917)
  * Update pre-commit hooks (#970)
  * DOCS: Fixed file path of logos (#969)
  * FIX: improve display of table in the nbsphinx context (#954)
  * ENH: Automatically shorten links for GitHub/GitLab (#957)
  * FIX: do not prettify primary sidebar html (#965)
  * MAINT: update icons to fit Fontawesome 6 (#963)
  * Align all the columns on the primary sidebar (#950)
  * DOCS: better document how to remove secondary sidebar
  * FIX: expand the bd-article-container (#964)
  * FIX: use target color for footnotes (#962)
  * FIX: Don't filter images that support the dark theme (#942)
  * Bump nth-check and optimize-css-assets-webpack-plugin (#882)
  * update Javascript dependencies (#940)
  * Build wheels for testing (#939)
  * Bump node-forge and webpack-dev-server (#883)
  * feat: add the indices to the optional sidebar components (#922)
  * FIX: use parent when self is use in a toctree (#938)
  * Add expected pandas 1.5 warning (#936)
  * MAINT: Open issue when dependency prereleases fail (#899)
  * DOCS: Add sepal to the gallery (#927)
  * Fix plausible loading (#909)
  * Add EnOSlib's website in the gallery (#919)
  * FIX: use hasdoc() for logo link (#921)
  * Add #searchbox to sidebar for "Hide Search Matches" link (#925)
  * ENH: Use bootstrap tooltip to display icons title (#924)
  * set the content at the top of the page (#916)
  * add css helper for images optimized for both dark and light theme (#914)
  * ENH: Use toctree titles in the header navbar (#915)
  * Correct the link to the pygments styles in styling.rst (#910)
  * RLS: v0.10.1
  * Don't test against prereleased dependecies (#900)
  * RLS: v0.10.0
  * ENH: Add section title to sidebar navigation (#895)
  * DOCS: Update grid size for gallery (#894)
  * ENH: option to customise the alt text of the logo (#893)
  * MAINT: Run audit on a simplified docs build (#892)
  * ENH: Simplify and speed up navigation bar links generation (#878)
  * MAINT: Add action for profiling (#888)
  * MAINT: Add a py-spy profiler to nox (#887)
  * DOCS: Improve sphinx-design card examples (#885)
  * MAINT: Upgrade FontAwesome dependency to latest version (#868)
  * BUG: Fix links not clickable in versionmodified directives (#877)
  * NEW: Adding a section for footer-content like in sphinx-basic-ng (#861)
  * fix: update switcher color according to sidebar (#880)
  * FIX: Fix equation scrolling behavior (#872)
  * fix color of the search input (#875)
  * FIX: Hide vert scrollbars on inline math (#871)
  * ENH: suppress autocorrect/spellcheck/autocapitalize in search box (#870)
  * Gallery (#867)
  * DOCS: Add arviz website to example gallery (#862)
  * Build docs w/ sphinx 5 (#864)
  * Fix links on homepage (#853)
  * Update GitHub Action for releases
  * RLS: v0.10.0RC2
  * ENH: Add download link icon to download links (#850)
  * Fix several CSS elements and bugs for Sphinx 5 (#818)
  * ENH: Improve sidebar secondary config and logic
  * ENH: Move header items to sidebar on mobile (#834)
  * DOC: Add comment to deprecate some CSS in future (#848)
  * fix admonition-sidebar styling (#847)
  * DOCS: Clarify analytics documentation (#839)
  * ENH: Add light background to inline code (#838)
  * DOCS: Update front page, contributing doc, and gallery code (#825)
  * ENH: Add plausible analytics (#828)
  * ENH: Allow admonitions to be style as a sidebar (#836)
  * Update kitchen sink and script to update (#819)
  * ENH: Search button shows up on mobile (#832)
  * Bump terser from 4.8.0 to 4.8.1 (#830)
  * Refactor and modularize user guide (#826)
  * ENH: Add ABlog support (#796)
  * Add dropdown support for Sphinx Design (#812)
  * MAINT: Move publish to new workflow (#816)
  * Add push events for tags (#815)
  * Release Candidate: v0.10.0rc1 (#813)
  * Inline math docs and optional keywords for favicons (#810)
  * Fixed Spelling and Style (#811)
  * Use Bootstrap styling for our dropdown button (#808)
  * Overlay darken for search popup (#804)
  * Update theme switch colors (#803)
  * Handle varied search field configurations (#807)
  * Add release and review/merging policies to our documentation (#779)
  * ENH: Add override `attributes` in icon_links (#685)
  * ENH: External logo image, nbsphinx spacing, admonition title (#797)
  * Let the PyPi badge in README.md link to the project page in PyPi (#798)
  * Fix usage of version dropdown to work on mobile (#790)
  * ENH: manage sidebars on small screens (#726)
  * Fix header spacing (#788)
  * Update topic and contents directive style (#785)
  * Style code blocks after GitHub (#784)
  * Fix typos, use logging.warning (#787)
  * ENH: Make scroll bar style more accessible and noticeable (#776)
  * FIX: Search bar and navigation dropdown style (#770)
  * FIX: Overflow content on configuration (#772)
  * FIX: Set minimum version of supported pygments (#778)
  * Add color support for copy and toggle buttons (#767)
  * Add dropdown menu to header navigation (#754)
  * Remove pa11y (#751)
  * Add NBSphinx support for dark theme (#741)
  * ENH: White space behavior for main content (#753)
  * DOCS: Explain terminology and layout (#756)
  * NEW: Adding announcement banners (#722)
  * Only install Chromium with Playwright (#750)
  * ENH: Make search field an overlay with button click (#744)
  * DOCS: improve color documentation (#742)
  * MAINT: Add pyupgrade pre-commit hook (#712)
  * DOCS: Add a dynamic gallery of projects (#700)
  * ENH: Use JupyterLab cell background color for surface variables (#747)
  * ENH: Simplify theme variable code and support Sphinx Design (#746)
  * ENH: Improve quotes display CSS (#743)
  * FIX: Typos in readme (#740)
  * DOCS: Add feature-engine to list of projects (#725)
  * DOC: Fix spelling error (#738)
  * Add: Sourcelink and other Sphinx theme templates (#714)
  * DOC: Clarify `theme` wording in docs (#736)
  * ENH: Add dark mode support for some pydata packages (#723)
  * MAINT: Ignore black format changes (#713)
  * FIX: Make hover color work on version switcher (#731)
  * FIX: Rendering external URL in logo.link option (#734)
  * Fix color regression in sphinx_design and sphinx_panels (#728)
  * ENH: equations display on small screen (#718)
  * ENH: Version switcher dark mode support (#719)
  * fix package versions (#715)
  * force table to fit in the article width (#717)
  * Bump version
  * RLS: v0.9.0
  * Add logo and update brand colors (#698)
  * Use myst-parser 0.18 (#703)
  * Style the toctree (#693)
  * Use different logos for light and dark theme (#691)
  * Prevent theme mamangement to raise error when the mode is fixed (#692)
  * Improve table captions (#695)
  * Manage the bottom of small pages (#694)
  * Center align all elements in the navbar (#697)
  * Add acknowledgment section (#696)
  * Add Sphinx and Python version support policy (#679)
  * MAINT: Docutils 0.18 deprecation (#687)
  * move all the CSS variable to a single folder (#686)
  * Test against prereleases (#683)
  * Update configuring.rst (#682)
  * Bump release
  * RLS: v0.9.0rc1
  * Bump version
  * Pin Sphinx to >= 4.0.2 (#678)
  * Rename master branch main (#666)
  * Moving some template links to Python (#672)
  * ENH: simplify color variables (#659)
  * Remove upperbound on sphinx (#661)
  * Add panels support (#641)
  * Add classes for multi-theme content support (#673)
  * Support Sphinx 5 (#668)
  * Update GH actions versions (#670)
  * Update pre-commit hooks (#667)
  * Rearrange sections to use basic-ng names (#662)
  * DOC: Add the mastodon fediverse icon as example. (#646)
  * ENH: Clean up navbar spacing on mobile (#644)
  * Increase scrollspy amount (#657)
  * ENH: Scrollbar styling (#637)
  * Add missing release in version switcher (#656)
  * Add deprecation warning for switcher (#655)
  * [switcher] default `activeVersion` and `activeVersionName` values (#654)
  * Update docs on version switcher dictionary (#653)
  * customize display of line numbers in code-block (#651)
  * fix: apply the centered directive (#652)
  * Update example to correspond to new Google Analytics ID (#650)
  * Clarify use-case and docs structure (#648)
  * DOCS: how to create an inline footer (#636)
  * FIX: Avoid secondary navbar overlap (#642)
  * ENH: Adapt target viewcode to tango highlighting style (#635)
  * Show the right sidebar on wider screens if the left is hidden (#570)
  * Refactor SCSS structure (#619)
  * DOC: Document helper for dark mode (#626)
  * ENH: Minor updates and tweaks to Dark theme CSS (#631)
  * ENH: Dark theme support for ethical ads
  * Add dark theme and theme switcher (#540)
  * Add a url type for navbar icons (#616)
  * Update black pre-commit (#618)
  * Set lighthouse to run on kitchen sink (#612)
  * RELEASE: v0.8.1 (#611)
  * add link to pyvista (#606)
  * Fix typos (#608)
  * ENH: Left navigation menu to collapse at the "part" level (#594)
  * Remove double-linking of theme CSS (#598)
  * Version switcher provides explicit URLs (#604)
  * Use dataclasses instead of extra_classes (#597)
  * Allow relative json url to work locally (and hopefully on PRs) (#599)
  * Make header links non-selectable (#602)
  * Bump to dev version + update versions in switcher.json (#574)
  * Pin sphinx to >=3.5.4,<5 (#595)
  * STYLE: Update default anchor link (#593)
  * DOCS: Clarify instructions about modifying search bar position (#586)
  * Replace distutils Version class with `packaging.version` (#590)
  * ENH: add optional `extra_classes` in version-switcher (#576)
  * TEST: Basic test for our switcher (#584)
  * ENH: add optional per version url in version-switcher (#575)
  * MAINT: New action for lighthouse (#572)
  * Reduce border-radius on search bar (#581)
  * Use margin instead of padding to offset "On this page"
  * Reduce scroll-spy offset by 20px
  * Don't offset body by 20px
  * Don't offset toc and sidebar by 20px
  * Improve sidebar search presentation
  * CLN: use str instead of os.fsdecode for converting Path (#569)
  * FIX: use str theme path for compat with older jinja2 versions (#565)
  * DOCS: Add Matplotlib to index.rst... (#563)
  * RELEASE: v0.8.0 (#562)
  * DOCS: Refactor demo docs (#544)
  * UPDATE: NodeJS 16.x (#552)
  * FIX: Field lists bug (#554)
  * FIX: Admonitions margin (#550)
  * FIX: Left scroll JS proper selector (#534)
  * ENH: Add left sidebar end section to bottom (#543)
  * DOCS: refactor developer docs (#538)
  * FIX: Navbar margin on mobile (#541)
  * END: Add ability to specify custom icon images (#542)
  * MAINT: Add OSX and Windows build to tests (#533)
  * Revert "RLS: v0.8.0 (#530)" (#531)
  * RLS: v0.8.0 (#530)
  * STYLE: Improve spacing for non-image site title (#526)
  * Add step to install needed dependencies to build the site (#520)
  * drop python 3.6 + use python action cache
  * clean-up
  * fix path?
  * temporary upload sdist/wheel to check release workflow
  * quote 3.10
  * CI: update github action workflow after sphinx-theme-builder switch
  * ✨ NEW: add version switcher (#436)
  * Simplify linting setup
  * Improve webpack-macros.html generation logic
  * Enable source map for the generated JS file
  * Add a comment about what ?-url means
  * Drop `make` stuff from docs/
  * Rework theme to utilise `sphinx-theme-builder`
  * Drop Python 3.6 support
  * rebuild assets
  * Add prettier to pre-commit hooks
  * Add a few pre-commit hooks for consistency across files
  * Prettify the .pre-commit-config.yaml file
  * Fixing environment.yml for noxfile (#512)
  * FIX: Compatibility with sphinx 4.3 (visit_table) (#509)
  * DEV: Simplify webpack and codebase (#495)
  * ENH: Add nav show feature (#493)
  * Fix nox install task to work with --no-venv (#505)
  * Document how to remove toctrees from pages (#492)
  * Recommonmark -> MyST and docs (#499)
  * Make the whole left sidebar scrollable (#502)
  * feat: add a versionmodified css file (#498)
  * DEV: fix nox check for sphinx already being installed (#494)
  * Improving noxfile speed (#491)
  * Improve developer workflow and docs (#490)
  * fix dependency installation and build (#467)
* Fri Feb 24 2023 daniel.garcia@suse.com
- Update to version 0.12.0:
  * RLS: v0.12.0
  * FIX: remove double quotes in github actions (#1062)
  * RLS: v0.12.0rc1 (#1057)
  * FIX: display external links in toctree (#1055)
  * STYLE: style admonitions (#1043)
  * Build(deps): Bump loader-utils from 1.4.0 to 1.4.1 (#1053)
  * FIX: use warning instead of errors for version json tests (#993)
  * ENH: Add GitHub Projects support for github shorten links (#1051)
  * FIX: Navigation buttons accessibility fixes (#1050)
  * ENH: Refactor gitlab parsing in ShortenLinkTransform (#1039) (#1048)
  * Disable CloudFlare Rocket loader on dark mode script (#1045)
  * Prerelease CI: Update name, schedule and Python version (#1044)
  * Change pypa/gh-action-pypi-publish to use stable release branch (#1047)
  * Add Dependabot configuration for GitHub Actions updates (#1046)
  * FIX: style table generated by myst-NB (#1041)
  * MAINT: refactor webpack.config.js (#1035)
  * ENH: support seealso admonition (#1037)
  * DOCS: update documentation link (#1033)
  * DOCS: fix python block in keyboard-shortcuts.md (#1032)
  * MAINT: split bootstrap and theme styling (#994)
  * ENH: Add skip to main content button for a11y (#1019)
  * MAINT: use a function to test the warnings of the CI doc build (#1002)
  * FIX: avoid API double select (#1015)
  * FIX: table width of nbsphinx dataframes (#1018)
  * DOCS: demonstrate inline highlighting (#1025)
  * ENH: create a navbar_persistent section (#1022)
  * ENH: place the RDT flyout in the sidebar (#1005)
  * FIX: update switcher list (#1009)
  * FIX: link shortening for gitlab (#1012)
  * FIX: make the icons available to implicit component (#991)
  * FIX: set back the icon inside the search bar (#992)
  * ENH: add the theme version in the footer (#1000)
  * FIX: avoid conflict between black and flake8
  * FIX: improve numbering of the docs (#1004)
  * fix: remove deprecated config (#997)
  * Remove deprecated option for google analytics (#975)
  * Remove travis/doctr cruft (#995)
  * Rename and add deprecation warnings for section names (#988)
  * FIX: change dark highlight for a11y (#985)
  * FIX: improve display of Hide search button (#984)
  * FIX: improve display of "side" docstring title (#981)
  * FIX: respect the align and width parameter of table directives (#968)
  * FIX: display math characters in the header navbar (#971)
  * Bump version
  * RLS: v0.11.0
  * fix: remove primary sidebar if empty (#980)
  * Bump version
  * RLS: v0.11.0rc3
  * Support Sphinx 4.2+ (#978)
  * Bump version
  * RLS: v0.11.0rc2
  * Fix for publishing prereleases (#974)
  * RLS: v0.11.0rc1
  * Test on Python 3.11 (#972)
  * FIX: check the json switcher file (#917)
  * Update pre-commit hooks (#970)
  * DOCS: Fixed file path of logos (#969)
  * FIX: improve display of table in the nbsphinx context (#954)
  * ENH: Automatically shorten links for GitHub/GitLab (#957)
  * FIX: do not prettify primary sidebar html (#965)
  * MAINT: update icons to fit Fontawesome 6 (#963)
  * Align all the columns on the primary sidebar (#950)
  * DOCS: better document how to remove secondary sidebar
  * FIX: expand the bd-article-container (#964)
  * FIX: use target color for footnotes (#962)
  * FIX: Don't filter images that support the dark theme (#942)
  * Bump nth-check and optimize-css-assets-webpack-plugin (#882)
  * update Javascript dependencies (#940)
  * Build wheels for testing (#939)
  * Bump node-forge and webpack-dev-server (#883)
  * feat: add the indices to the optional sidebar components (#922)
  * FIX: use parent when self is use in a toctree (#938)
  * Add expected pandas 1.5 warning (#936)
  * MAINT: Open issue when dependency prereleases fail (#899)
  * DOCS: Add sepal to the gallery (#927)
  * Fix plausible loading (#909)
  * Add EnOSlib's website in the gallery (#919)
  * FIX: use hasdoc() for logo link (#921)
  * Add #searchbox to sidebar for "Hide Search Matches" link (#925)
  * ENH: Use bootstrap tooltip to display icons title (#924)
  * set the content at the top of the page (#916)
  * add css helper for images optimized for both dark and light theme (#914)
  * ENH: Use toctree titles in the header navbar (#915)
  * Correct the link to the pygments styles in styling.rst (#910)
  * RLS: v0.10.1
  * Don't test against prereleased dependecies (#900)
  * RLS: v0.10.0
  * ENH: Add section title to sidebar navigation (#895)
  * DOCS: Update grid size for gallery (#894)
  * ENH: option to customise the alt text of the logo (#893)
  * MAINT: Run audit on a simplified docs build (#892)
  * ENH: Simplify and speed up navigation bar links generation (#878)
  * MAINT: Add action for profiling (#888)
  * MAINT: Add a py-spy profiler to nox (#887)
  * DOCS: Improve sphinx-design card examples (#885)
  * MAINT: Upgrade FontAwesome dependency to latest version (#868)
  * BUG: Fix links not clickable in versionmodified directives (#877)
  * NEW: Adding a section for footer-content like in sphinx-basic-ng (#861)
  * fix: update switcher color according to sidebar (#880)
  * FIX: Fix equation scrolling behavior (#872)
  * fix color of the search input (#875)
  * FIX: Hide vert scrollbars on inline math (#871)
  * ENH: suppress autocorrect/spellcheck/autocapitalize in search box (#870)
  * Gallery (#867)
  * DOCS: Add arviz website to example gallery (#862)
  * Build docs w/ sphinx 5 (#864)
  * Fix links on homepage (#853)
  * Update GitHub Action for releases
  * RLS: v0.10.0RC2
  * ENH: Add download link icon to download links (#850)
  * Fix several CSS elements and bugs for Sphinx 5 (#818)
  * ENH: Improve sidebar secondary config and logic
  * ENH: Move header items to sidebar on mobile (#834)
  * DOC: Add comment to deprecate some CSS in future (#848)
  * fix admonition-sidebar styling (#847)
  * DOCS: Clarify analytics documentation (#839)
  * ENH: Add light background to inline code (#838)
  * DOCS: Update front page, contributing doc, and gallery code (#825)
  * ENH: Add plausible analytics (#828)
  * ENH: Allow admonitions to be style as a sidebar (#836)
  * Update kitchen sink and script to update (#819)
  * ENH: Search button shows up on mobile (#832)
  * Bump terser from 4.8.0 to 4.8.1 (#830)
  * Refactor and modularize user guide (#826)
  * ENH: Add ABlog support (#796)
  * Add dropdown support for Sphinx Design (#812)
  * MAINT: Move publish to new workflow (#816)
  * Add push events for tags (#815)
  * Release Candidate: v0.10.0rc1 (#813)
  * Inline math docs and optional keywords for favicons (#810)
  * Fixed Spelling and Style (#811)
  * Use Bootstrap styling for our dropdown button (#808)
  * Overlay darken for search popup (#804)
  * Update theme switch colors (#803)
  * Handle varied search field configurations (#807)
  * Add release and review/merging policies to our documentation (#779)
  * ENH: Add override `attributes` in icon_links (#685)
  * ENH: External logo image, nbsphinx spacing, admonition title (#797)
  * Let the PyPi badge in README.md link to the project page in PyPi (#798)
  * Fix usage of version dropdown to work on mobile (#790)
  * ENH: manage sidebars on small screens (#726)
  * Fix header spacing (#788)
  * Update topic and contents directive style (#785)
  * Style code blocks after GitHub (#784)
  * Fix typos, use logging.warning (#787)
  * ENH: Make scroll bar style more accessible and noticeable (#776)
  * FIX: Search bar and navigation dropdown style (#770)
  * FIX: Overflow content on configuration (#772)
  * FIX: Set minimum version of supported pygments (#778)
  * Add color support for copy and toggle buttons (#767)
  * Add dropdown menu to header navigation (#754)
  * Remove pa11y (#751)
  * Add NBSphinx support for dark theme (#741)
  * ENH: White space behavior for main content (#753)
  * DOCS: Explain terminology and layout (#756)
  * NEW: Adding announcement banners (#722)
  * Only install Chromium with Playwright (#750)
  * ENH: Make search field an overlay with button click (#744)
  * DOCS: improve color documentation (#742)
  * MAINT: Add pyupgrade pre-commit hook (#712)
  * DOCS: Add a dynamic gallery of projects (#700)
  * ENH: Use JupyterLab cell background color for surface variables (#747)
  * ENH: Simplify theme variable code and support Sphinx Design (#746)
  * ENH: Improve quotes display CSS (#743)
  * FIX: Typos in readme (#740)
  * DOCS: Add feature-engine to list of projects (#725)
  * DOC: Fix spelling error (#738)
  * Add: Sourcelink and other Sphinx theme templates (#714)
  * DOC: Clarify `theme` wording in docs (#736)
  * ENH: Add dark mode support for some pydata packages (#723)
  * MAINT: Ignore black format changes (#713)
  * FIX: Make hover color work on version switcher (#731)
  * FIX: Rendering external URL in logo.link option (#734)
  * Fix color regression in sphinx_design and sphinx_panels (#728)
  * ENH: equations display on small screen (#718)
  * ENH: Version switcher dark mode support (#719)
  * fix package versions (#715)
  * force table to fit in the article width (#717)
  * Bump version
  * RLS: v0.9.0
  * Add logo and update brand colors (#698)
  * Use myst-parser 0.18 (#703)
  * Style the toctree (#693)
  * Use different logos for light and dark theme (#691)
  * Prevent theme mamangement to raise error when the mode is fixed (#692)
  * Improve table captions (#695)
  * Manage the bottom of small pages (#694)
  * Center align all elements in the navbar (#697)
  * Add acknowledgment section (#696)
  * Add Sphinx and Python version support policy (#679)
  * MAINT: Docutils 0.18 deprecation (#687)
  * move all the CSS variable to a single folder (#686)
  * Test against prereleases (#683)
  * Update configuring.rst (#682)
  * Bump release
  * RLS: v0.9.0rc1
  * Bump version
  * Pin Sphinx to >= 4.0.2 (#678)
  * Rename master branch main (#666)
  * Moving some template links to Python (#672)
  * ENH: simplify color variables (#659)
  * Remove upperbound on sphinx (#661)
  * Add panels support (#641)
  * Add classes for multi-theme content support (#673)
  * Support Sphinx 5 (#668)
  * Update GH actions versions (#670)
  * Update pre-commit hooks (#667)
  * Rearrange sections to use basic-ng names (#662)
  * DOC: Add the mastodon fediverse icon as example. (#646)
  * ENH: Clean up navbar spacing on mobile (#644)
  * Increase scrollspy amount (#657)
  * ENH: Scrollbar styling (#637)
  * Add missing release in version switcher (#656)
  * Add deprecation warning for switcher (#655)
  * [switcher] default `activeVersion` and `activeVersionName` values (#654)
  * Update docs on version switcher dictionary (#653)
  * customize display of line numbers in code-block (#651)
  * fix: apply the centered directive (#652)
  * Update example to correspond to new Google Analytics ID (#650)
  * Clarify use-case and docs structure (#648)
  * DOCS: how to create an inline footer (#636)
  * FIX: Avoid secondary navbar overlap (#642)
  * ENH: Adapt target viewcode to tango highlighting style (#635)
  * Show the right sidebar on wider screens if the left is hidden (#570)
  * Refactor SCSS structure (#619)
  * DOC: Document helper for dark mode (#626)
  * ENH: Minor updates and tweaks to Dark theme CSS (#631)
  * ENH: Dark theme support for ethical ads
  * Add dark theme and theme switcher (#540)
  * Add a url type for navbar icons (#616)
  * Update black pre-commit (#618)
  * Set lighthouse to run on kitchen sink (#612)
  * RELEASE: v0.8.1 (#611)
  * add link to pyvista (#606)
  * Fix typos (#608)
  * ENH: Left navigation menu to collapse at the "part" level (#594)
  * Remove double-linking of theme CSS (#598)
  * Version switcher provides explicit URLs (#604)
  * Use dataclasses instead of extra_classes (#597)
  * Allow relative json url to work locally (and hopefully on PRs) (#599)
  * Make header links non-selectable (#602)
  * Bump to dev version + update versions in switcher.json (#574)
  * Pin sphinx to >=3.5.4,<5 (#595)
  * STYLE: Update default anchor link (#593)
  * DOCS: Clarify instructions about modifying search bar position (#586)
  * Replace distutils Version class with `packaging.version` (#590)
  * ENH: add optional `extra_classes` in version-switcher (#576)
  * TEST: Basic test for our switcher (#584)
  * ENH: add optional per version url in version-switcher (#575)
  * MAINT: New action for lighthouse (#572)
  * Reduce border-radius on search bar (#581)
  * Use margin instead of padding to offset "On this page"
  * Reduce scroll-spy offset by 20px
  * Don't offset body by 20px
  * Don't offset toc and sidebar by 20px
  * Improve sidebar search presentation
  * CLN: use str instead of os.fsdecode for converting Path (#569)
  * FIX: use str theme path for compat with older jinja2 versions (#565)
  * DOCS: Add Matplotlib to index.rst... (#563)
  * RELEASE: v0.8.0 (#562)
  * DOCS: Refactor demo docs (#544)
  * UPDATE: NodeJS 16.x (#552)
  * FIX: Field lists bug (#554)
  * FIX: Admonitions margin (#550)
  * FIX: Left scroll JS proper selector (#534)
  * ENH: Add left sidebar end section to bottom (#543)
  * DOCS: refactor developer docs (#538)
  * FIX: Navbar margin on mobile (#541)
  * END: Add ability to specify custom icon images (#542)
  * MAINT: Add OSX and Windows build to tests (#533)
  * Revert "RLS: v0.8.0 (#530)" (#531)
  * RLS: v0.8.0 (#530)
  * STYLE: Improve spacing for non-image site title (#526)
  * Add step to install needed dependencies to build the site (#520)
  * drop python 3.6 + use python action cache
  * clean-up
  * fix path?
  * temporary upload sdist/wheel to check release workflow
  * quote 3.10
  * CI: update github action workflow after sphinx-theme-builder switch
  * ✨ NEW: add version switcher (#436)
  * Simplify linting setup
  * Improve webpack-macros.html generation logic
  * Enable source map for the generated JS file
  * Add a comment about what ?-url means
  * Drop `make` stuff from docs/
  * Rework theme to utilise `sphinx-theme-builder`
  * Drop Python 3.6 support
  * rebuild assets
  * Add prettier to pre-commit hooks
  * Add a few pre-commit hooks for consistency across files
  * Prettify the .pre-commit-config.yaml file
  * Fixing environment.yml for noxfile (#512)
  * FIX: Compatibility with sphinx 4.3 (visit_table) (#509)
  * DEV: Simplify webpack and codebase (#495)
  * ENH: Add nav show feature (#493)
  * Fix nox install task to work with --no-venv (#505)
  * Document how to remove toctrees from pages (#492)
  * Recommonmark -> MyST and docs (#499)
  * Make the whole left sidebar scrollable (#502)
  * feat: add a versionmodified css file (#498)
  * DEV: fix nox check for sphinx already being installed (#494)
  * Improving noxfile speed (#491)
  * Improve developer workflow and docs (#490)
  * fix dependency installation and build (#467)
* Mon Nov  8 2021 Dirk Müller <dmueller@suse.com>
- Update to 0.7.1:
  * Fixing prevnext translations (#486)
  * RLS: v0.7.0
  * Update API styling for changes in sphinx 4.x (#485)
  * Avoid adding margin to docutils container (from bootstrap container) (#474)
  * Add css for blockquote and references/citations (#482)
  * Move API docs related CSS to separate file (#476)
  * Improve styling of the Previous / Next buttons (#473)
  * 👌 Round edges (#472)
  * Bump docutils version (#463)
  * FIX: added gtag date and moved google analytics to header (#439)
  * Add explicit heading aria-level to complement heading role (#456)
  * revert style changes (#459)
  * include tests in sdist (#457)
  * Add pa11y testing and reporting (#294)
  * move parent theme css earlier in the inclusion order (#451)
  * FIX: Include built css/js assets in source again (#450)
  * Re-build assests with yarn to fix linting  (#448)
  * Bump url-parse from 1.5.1 to 1.5.3 (#443)
  * TST: update role for caption in expected html output (sphinx 4.1) (#441)
  * Remove CircleCI from jobs (#445)
  * Bump path-parse from 1.0.6 to 1.0.7 (#442)
  * Use a variable for the color of editthispage (#412)
  * Bump color-string from 1.5.3 to 1.6.0 (#440)
  * Bump postcss from 7.0.32 to 7.0.36 (#425)
  * fix Fairlearn link (#430)
  * DOC: Add a few more projects that have adopted the theme. (#423)
  * Fixing admonition title CSS (#407)
  * Add MNE-Python to theme users list (#405)
  * Bump dns-packet from 1.3.1 to 1.3.4 (#421)
  * Bump browserslist from 4.12.0 to 4.16.6 (#419)
  * Bump hosted-git-info from 2.8.8 to 2.8.9 (#411)
  * Bump url-parse from 1.4.7 to 1.5.1 (#409)
  * Bump ws from 6.2.1 to 6.2.2 (#422)
  * add pyvista to sites using the theme (#418)
  * Remove end tags from HTML elements (#408)
  * Bump lodash from 4.17.19 to 4.17.21 (#410)
  * Bump ssri from 6.0.1 to 6.0.2 (#406)
- drop fix_sidebar_tests.patch (upstream)
* Thu Aug 26 2021 mcepl@cepl.eu
- Update to version 0.6.3:
  * 🚀 RLS: v0.6.3
  * Fix regression with 'None' inserted in html by google analytics script (#404)
  * 🚀 RLS: v0.6.2
  * 🐛 FIX: fix undefined sphinx var "meta" in jinja (#395)
  * CI: add build with pre-release versions of sphinx and jinja2 (#402)
  * Support new+old Google analytics (#387)
  * Raise exception if icon_links conf val is not a dict. (#392)
  * i18n: Translate theme text variable (#398)
  * i18n: Translate text in HTML (#397)
  * i18n: Translate aria-label (#396)
* Thu Aug 26 2021 Matej Cepl <mcepl@suse.com>
- Initial package for pydata-sphinx-theme 0.6.3.
